@@ -66,7 +66,7 @@ class LWRFFeatureSet:
     def is_windowsensor(self): return self.has_feature('windowPosition')
     def is_hub(self): return self.has_feature('buttonPress')
 
-    def is_gen2(self): return self.has_feature('upgrade')
+    def is_gen2(self): return (self.has_feature('upgrade') or self.has_feature('uiButton'))
     def reports_power(self): return self.has_feature('power')
     def has_led(self): return self.has_feature('rgbColor')
 
@@ -155,8 +155,8 @@ class LWLink2:
                 mess = await self._websocket.receive()
                 _LOGGER.debug("consumer_handler: Received %s", mess)
             except AttributeError:  # websocket is None if not set up, just wait for a while
-                _LOGGER.debug("consumer_handler: websocket not ready, sleeping for 1 sec")
-                await asyncio.sleep(1)
+                _LOGGER.debug("consumer_handler: websocket not ready, sleeping for 0.1 sec")
+                await asyncio.sleep(0.1)
             except Exception as exp:
                 _LOGGER.warning("consumer_handler: unhandled exception ('{}')".format(exp))
             else:
@@ -581,7 +581,7 @@ class LWLink2Public(LWLink2):
 
             for x in response["devices"]:
                 for y in x["featureSets"]:
-                    _LOGGER.debug("async_get_hierarchy: Creating device {}".format(x))
+                    _LOGGER.debug("async_get_hierarchy: Creating device {}".format(y))
                     new_featureset = LWRFFeatureSet()
                     new_featureset.link = self
                     new_featureset.featureset_id = y["featureSetId"]
@@ -708,5 +708,9 @@ class LWLink2Public(LWLink2):
         await self._get_access_token()
         return True
 
+    async def async_force_reconnect(self, secs):
+        _LOGGER.debug("async_force_reconnect: not implemented for public API, skipping")
+
+
 
 
